/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.crud;

import java.util.List;
import java.util.Map;

/**
 * {@link Query}のファクトリ。
 * 適用しているパターン：Abstract Factory。
 * @author nakamura
 *
 */
public interface QueryFactory {
	/**
	 * {@link Query}を生成して返す。
	 * @param id 識別子。
	 * @param map 属性名と属性値の一覧。
	 * @return 識別子と属性名の一覧に対応する{@link Query}。
	 */
	Query newInstance(String id, Map<String, List<Object>> map);
}
