/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.dom;

import woolpack.utils.CheckUtils;

/**
 * 委譲先から復帰したときに{@link DomContext#setId(String)}を初期化する{@link DomExpression}。
 * 
 * @author nakamura
 * 
 */
public class ResetId implements DomExpression {
	private final DomExpression expression;

	/**
	 * コンストラクタ。
	 * 
	 * @param expression
	 *            委譲先。
	 * @throws NullPointerException
	 *             引数が null の場合。
	 */
	public ResetId(final DomExpression expression) {
		CheckUtils.checkNotNull(expression);
		this.expression = expression;
	}

	/**
	 * @throws NullPointerExcpeption
	 *             引数が null の場合。
	 */
	public void interpret(final DomContext context) {
		final String id = context.getId();
		try {
			expression.interpret(context);
		} finally {
			context.setId(id);
		}
	}
}
