/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.text;

import java.text.NumberFormat;
import java.text.ParsePosition;

/**
 * 文字列を解析して{@link Double}に変換する変換器。
 * 
 * @author nakamura
 * 
 */
public class ToDoubleFormat extends DelegateNumberFormat {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * コンストラクタ。
	 * 
	 * @param format
	 *            数値変換の委譲先。
	 * @throws NullPointerException
	 *             引数が null の場合。
	 */
	public ToDoubleFormat(final NumberFormat format) {
		super(format);
	}

	/**
	 * コンストラクタ。 {@link java.text.DecimalFormat}を数値変換の委譲先とする。
	 */
	public ToDoubleFormat() {
		super();
	}

	@Override
	public Number parse(
			final String source,
			final ParsePosition parsePosition) {
		final Number n = super.parse(source, parsePosition);
		if (n != null) {
			return Double.valueOf(n.doubleValue());
		}
		return null;
	}
}
