/*
 * Copyright 2006 Takahiro Nakamura.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package woolpack.validator;

import java.util.Collection;

import woolpack.utils.CheckUtils;

/**
 * 指定されたプロパティ名を残し、指定されていないプロパティ名を削除する{@link ValidatorExpression}。
 * 
 * @author nakamura
 * 
 */
public class RetainNamesValidator implements ValidatorExpression {
	private final Collection<String> collection;

	/**
	 * コンストラクタ。
	 * 
	 * @param collection
	 *            残す文字列の集合。本クラスはこの引数の状態を変化させない。
	 * @throws NullPointerException
	 *             引数が null の場合。
	 */
	public RetainNamesValidator(final Collection<String> collection) {
		CheckUtils.checkNotNull(collection);
		this.collection = collection;
	}

	/**
	 * @throws NullPointerException
	 *             引数または{@link ValidatorContext#getInputMap()()}が null の場合。
	 */
	public boolean interpret(final ValidatorContext context) {
		context.getInputMap().keySet().retainAll(collection);
		return true;
	}

	public Collection<String> getCollection() {
		return collection;
	}
}
